@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 4; indent-tabs-mode: t; c-basic-offset: 4 -*-
  *
- * * Copyright (C) 2008 Ali <aliov@xfce.org>
+ * * Copyright (C) 2008-2011 Ali <aliov@xfce.org>
  *
  * Licensed under the GNU General Public License Version 2
  *
@@ -58,6 +58,10 @@ G_BEGIN_DECLS
 #define     	BRIGHTNESS_ON_AC             	"brightness-on-ac"
 #define     	BRIGHTNESS_ON_BATTERY        	"brightness-on-battery"
 
+
+#define     	BRIGHTNESS_LEVEL_ON_AC          "brightness-level-on-ac"
+#define     	BRIGHTNESS_LEVEL_ON_BATTERY     "brightness-level-on-battery"
+
 #define     	CRITICAL_POWER_LEVEL        	"critical-power-level"
 #define     	SHOW_BRIGHTNESS_POPUP        	"show-brightness-popup"
 #define     	ENABLE_BRIGHTNESS_CONTROL       "change-brightness-on-key-events"
