@@ -1,5 +1,5 @@
 /*
- * * Copyright (C) 2008-2009 Ali <aliov@xfce.org>
+ * * Copyright (C) 2008-2011 Ali <aliov@xfce.org>
  *
  * Licensed under the GNU General Public License Version 2
  *
@@ -93,6 +93,7 @@ typedef enum
     BUTTON_MON_BRIGHTNESS_UP,
     BUTTON_MON_BRIGHTNESS_DOWN,
     BUTTON_LID_CLOSED,
+    BUTTON_BATTERY,
     NUMBER_OF_BUTTONS
     
 } XfpmButtonKey;
@@ -106,6 +107,13 @@ typedef enum
     
 } XfpmShowIcon;
 
+typedef enum
+{
+    XFPM_POWER_MODE_NORMAL,
+    XFPM_POWER_MODE_PRESENTATION
+    
+} XfpmPowerMode;
+
 G_END_DECLS
 
 #endif /* __XFPM_ENUM_GLIB_H */
