@@ -20,6 +20,8 @@ GType xfpm_button_key_get_type (void);
 #define XFPM_TYPE_BUTTON_KEY (xfpm_button_key_get_type())
 GType xfpm_show_icon_get_type (void);
 #define XFPM_TYPE_SHOW_ICON (xfpm_show_icon_get_type())
+GType xfpm_power_mode_get_type (void);
+#define XFPM_TYPE_POWER_MODE (xfpm_power_mode_get_type())
 G_END_DECLS
 
 #endif /* _XFPM_ENUM_TYPES_H__ */
