@@ -323,15 +323,13 @@ xfpm_power_sleep (XfpmPower *power, const gchar *sleep_time, gboolean force)
     if ( power->priv->inhibited && force == FALSE)
     {
 	gboolean ret;
-	
+
 	ret = xfce_dialog_confirm (NULL,
-				   GTK_STOCK_YES,
-				   "Yes",
-				   _("An application is currently disabling the automatic sleep,"
-				   " doing this action now may damage the working state of this application,"
-				   " are you sure you want to hibernate the system?"),
-				   NULL);
-				   
+				   GTK_STOCK_OK, _("_Hibernate"),
+				   _("An application is currently disabling the automatic sleep. "
+				     "Doing this action now may damage the working state of this application."),
+				   _("Are you sure you want to hibernate the system?"));
+
 	if ( !ret )
 	    return;
     }
@@ -439,6 +437,7 @@ xfpm_power_tray_exit_activated_cb (gpointer data)
 static void
 xfpm_power_change_mode (XfpmPower *power, XfpmPowerMode mode)
 {
+#ifdef HAVE_DPMS
     XfpmDpms *dpms;
     
     power->priv->power_mode = mode;
@@ -455,6 +454,7 @@ xfpm_power_change_mode (XfpmPower *power, XfpmPowerMode mode)
     
 	g_object_unref (idletime);
     }
+#endif
 }
 
 static void
